pub struct AuthenticationPolicyDefinition {
pub use_: Option<String>,
pub basic: Option<BasicAuthenticationSchemeDefinition>,
pub bearer: Option<BearerAuthenticationSchemeDefinition>,
pub certificate: Option<CertificateAuthenticationSchemeDefinition>,
pub digest: Option<DigestAuthenticationSchemeDefinition>,
pub oauth2: Option<OAuth2AuthenticationSchemeDefinition>,
pub oidc: Option<OpenIDConnectSchemeDefinition>,
}Expand description
Represents the definition of an authentication policy
Fields
use_: Option<String>Gets/sets the name of the top level authentication policy to use, if any
basic: Option<BasicAuthenticationSchemeDefinition>Gets/sets the basic authentication scheme to use, if any
bearer: Option<BearerAuthenticationSchemeDefinition>Gets/sets the Bearer authentication scheme to use, if any
certificate: Option<CertificateAuthenticationSchemeDefinition>Gets/sets the Certificate authentication scheme to use, if any
digest: Option<DigestAuthenticationSchemeDefinition>Gets/sets the Digest authentication scheme to use, if any
oauth2: Option<OAuth2AuthenticationSchemeDefinition>Gets/sets the OAUTH2 authentication scheme to use, if any
oidc: Option<OpenIDConnectSchemeDefinition>Gets/sets the OIDC authentication scheme to use, if any