pub struct OAuth2AuthenticationClientDefinition {
pub id: Option<String>,
pub secret: Option<String>,
pub assertion: Option<String>,
pub authentication: Option<String>,
}Expand description
Represents the definition of an OAUTH2 client
Fields
id: Option<String>Gets/sets the OAUTH2 client_id to use. Required if ‘Authentication’ has NOT been set to ‘none’.
secret: Option<String>Gets/sets the OAUTH2 client_secret to use, if any
assertion: Option<String>Gets/sets a JWT, if any, containing a signed assertion with the application credentials
authentication: Option<String>Gets/sets the authentication method to use to authenticate the client. Defaults to ‘client_secret_post’