pub struct OpenIDConnectSchemeDefinition {
pub use_: Option<String>,
pub authority: Option<String>,
pub grant: Option<String>,
pub client: Option<OAuth2AuthenticationClientDefinition>,
pub request: Option<OAuth2AuthenticationRequestDefinition>,
pub issuers: Option<Vec<String>>,
pub scopes: Option<Vec<String>>,
pub audiences: Option<Vec<String>>,
pub username: Option<String>,
pub password: Option<String>,
pub subject: Option<OAuth2TokenDefinition>,
pub actor: Option<OAuth2TokenDefinition>,
}Expand description
Represents the definition of an OpenIDConnect authentication scheme
Fields
use_: Option<String>Gets/sets the name of the secret, if any, used to configure the authentication scheme
Gets/sets the URI that references the OAUTH2 authority to use.
grant: Option<String>Gets/sets the grant type to use.
client: Option<OAuth2AuthenticationClientDefinition>Gets/sets the definition of the client to use.
request: Option<OAuth2AuthenticationRequestDefinition>Gets/sets the configuration of the authentication request to perform.
issuers: Option<Vec<String>>Gets/sets a list of valid issuers for token checks.
scopes: Option<Vec<String>>Gets/sets the scopes to request the token for.
audiences: Option<Vec<String>>Gets/sets the audiences to request the token for.
username: Option<String>Gets/sets the username to use (for Password grant).
password: Option<String>Gets/sets the password to use (for Password grant).
subject: Option<OAuth2TokenDefinition>Gets/sets the token representing the identity of the party on whose behalf the request is made.
actor: Option<OAuth2TokenDefinition>Gets/sets the token representing the acting party’s identity.