pub struct A2AArguments {
pub agent_card: Option<ExternalResourceDefinition>,
pub server: Option<OneOfEndpointDefinitionOrUri>,
pub method: String,
pub parameters: Option<OneOfA2AParametersOrExpression>,
}Expand description
Represents the A2A call arguments
Fields
agent_card: Option<ExternalResourceDefinition>Gets/sets the Agent Card that defines the agent to call
server: Option<OneOfEndpointDefinitionOrUri>Gets/sets the server endpoint to send the request to
method: StringGets/sets the A2A method to send
parameters: Option<OneOfA2AParametersOrExpression>Gets/sets the parameters object to send with the A2A method