pub struct AsyncApiSubscriptionDefinition {
pub filter: Option<String>,
pub consume: AsyncApiMessageConsumptionPolicy,
pub foreach: Option<SubscriptionIteratorDefinition>,
}Expand description
Represents an AsyncAPI subscription
Fields
filter: Option<String>Gets/sets a runtime expression, if any, used to filter consumed messages
consume: AsyncApiMessageConsumptionPolicyGets/sets the subscription’s message consumption policy
foreach: Option<SubscriptionIteratorDefinition>Gets/sets the configuration of the iterator, if any, for processing each consumed item