pub struct GRPCArguments {
pub proto: ExternalResourceDefinition,
pub service: GRPCServiceDefinition,
pub method: String,
pub arguments: Option<HashMap<String, Value>>,
pub authentication: Option<ReferenceableAuthenticationPolicy>,
}Expand description
Represents the GRPC call arguments
Fields
proto: ExternalResourceDefinitionGets/sets the proto resource that describes the GRPC service to call
service: GRPCServiceDefinitionGets/sets the GRPC service definition
method: StringGets/sets the name of the method to call on the defined GRPC service
arguments: Option<HashMap<String, Value>>Gets/sets the arguments, if any, to call the method with
authentication: Option<ReferenceableAuthenticationPolicy>Gets/sets the authentication policy, if any, to use when calling the GRPC service