pub enum OneOfDurationOrIso8601Expression {
Duration(Duration),
Iso8601Expression(String),
}Expand description
Represents a value that can be either a Duration or an ISO 8601 duration expression
Variants
Duration(Duration)
Variant holding a duration
Iso8601Expression(String)
Variant holding an ISO 8601 duration expression
Implementations
Sourceimpl OneOfDurationOrIso8601Expression
impl OneOfDurationOrIso8601Expression
Sourcepub fn total_milliseconds(&self) -> u64
pub fn total_milliseconds(&self) -> u64
Gets the total milliseconds for inline Duration variant. Returns 0 for ISO8601 expression variant (needs runtime parsing).
Sourcepub fn is_duration(&self) -> bool
pub fn is_duration(&self) -> bool
Returns true if this is an inline Duration variant
Sourcepub fn is_iso8601(&self) -> bool
pub fn is_iso8601(&self) -> bool
Returns true if this is an ISO8601 expression variant
Sourcepub fn as_iso8601(&self) -> Option<&str>
pub fn as_iso8601(&self) -> Option<&str>
Gets the ISO8601 expression string, if this is an expression variant