Module error

Module error 

Structs

ErrorDefinition
Represents the definition an error to raise, following RFC 7807 (Problem Details)
ErrorType
Represents the type of an error, which can be either a URI template or a runtime expression.
ErrorTypes
Standard error type URIs based on the Serverless Workflow specification

Enums

OneOfErrorDefinitionOrReference
A error definition or a reference to one