CorrelationKeyDefinition

Struct CorrelationKeyDefinition 

pub struct CorrelationKeyDefinition {
    pub from: String,
    pub expect: Option<String>,
}
Represents the definition of an event correlation key

Fields

from: String

Gets/sets a runtime expression used to extract the correlation key value from events

expect: Option<String>

Gets/sets a constant or a runtime expression, if any, used to determine whether or not the extracted correlation key value matches expectations and should be correlated. If not set, the first extracted value will be used as the correlation key’s expectation

Implementations

Source

impl CorrelationKeyDefinition

pub fn new(from: &str, expect: Option<String>) -> Self