pub struct ExtensionDefinition {
pub extend: String,
pub when: Option<String>,
pub before: Option<Vec<HashMap<String, TaskDefinition>>>,
pub after: Option<Vec<HashMap<String, TaskDefinition>>>,
}Expand description
Represents the definition of an extension
Fields
extend: StringGets/sets the type of task to extend
when: Option<String>Gets/sets a runtime expression, if any, used to determine whether or not the extension should apply in the specified context
before: Option<Vec<HashMap<String, TaskDefinition>>>Gets/sets a name/definition list, if any, of the tasks to execute before the extended task
after: Option<Vec<HashMap<String, TaskDefinition>>>Gets/sets a name/definition list, if any, of the tasks to execute after the extended task