pub struct InputDataModelDefinition {
pub schema: Option<SchemaDefinition>,
pub from: Option<Value>,
}Expand description
Represents the definition of an input data model
Fields
schema: Option<SchemaDefinition>Gets/sets the schema, if any, that defines and describes the input data of a workflow or task
from: Option<Value>Gets/sets a runtime expression, if any, used to build the workflow or task input data based on both input and scope data