pub struct OutputDataModelDefinition {
pub schema: Option<SchemaDefinition>,
pub as_: Option<Value>,
}Expand description
Represents the definition of an output data model
Fields
schema: Option<SchemaDefinition>Gets/sets the schema, if any, that defines and describes the output data of a workflow or task
as_: Option<Value>Gets/sets a runtime expression, if any, used to output specific data to the scope data