pub struct ExponentialBackoffDefinition {
pub definition: Option<HashMap<String, Value>>,
}Expand description
Represents the definition of an exponential backoff
Fields
definition: Option<HashMap<String, Value>>Gets/sets the definition of the exponential backoff parameters (e.g., {“factor”: 2, “maxDelay”: “PT30S”})
Implementations
Sourceimpl ExponentialBackoffDefinition
impl ExponentialBackoffDefinition
Sourcepub fn with_factor(factor: f64) -> Self
pub fn with_factor(factor: f64) -> Self
Creates an exponential backoff with a factor
Sourcepub fn with_factor_and_max_delay(factor: f64, max_delay: &str) -> Self
pub fn with_factor_and_max_delay(factor: f64, max_delay: &str) -> Self
Creates an exponential backoff with a factor and max delay