pub struct LinearBackoffDefinition {
pub increment: Option<Duration>,
pub definition: Option<HashMap<String, Value>>,
}Expand description
Represents the definition of a linear backoff
Fields
increment: Option<Duration>Gets/sets the linear incrementation to the delay between retry attempts
definition: Option<HashMap<String, Value>>Gets/sets the definition of additional linear backoff parameters (e.g., {“maxDelay”: “PT30S”})