pub struct RetryAttemptLimitDefinition {
pub count: Option<u16>,
pub duration: Option<OneOfDurationOrIso8601Expression>,
}Expand description
Represents the definition of the limits for all retry attempts of a given policy
Fields
count: Option<u16>Gets/sets the maximum attempts count
duration: Option<OneOfDurationOrIso8601Expression>Gets/sets the duration limit, if any, for all retry attempts