RetryPolicyDefinition

Struct RetryPolicyDefinition 

pub struct RetryPolicyDefinition {
    pub when: Option<String>,
    pub except_when: Option<String>,
    pub limit: Option<RetryPolicyLimitDefinition>,
    pub delay: Option<OneOfDurationOrIso8601Expression>,
    pub backoff: Option<BackoffStrategyDefinition>,
    pub jitter: Option<JitterDefinition>,
}
Represents the definition of a retry policy

Fields

when: Option<String>

Gets/sets a runtime expression used to determine whether or not to retry running the task, in a given context

except_when: Option<String>

Gets/sets a runtime expression used to determine whether or not to retry running the task, in a given context

limit: Option<RetryPolicyLimitDefinition>

Gets/sets the limits, if any, of the retry policy

delay: Option<OneOfDurationOrIso8601Expression>

Gets/sets the delay duration between retry attempts

backoff: Option<BackoffStrategyDefinition>

Gets/sets the backoff strategy to use, if any

jitter: Option<JitterDefinition>

Gets/sets the parameters, if any, that control the randomness or variability of the delay between retry attempts