pub struct RetryPolicyLimitDefinition {
pub attempt: Option<RetryAttemptLimitDefinition>,
pub duration: Option<OneOfDurationOrIso8601Expression>,
}Expand description
Represents the configuration of the limits of a retry policy
Fields
attempt: Option<RetryAttemptLimitDefinition>Gets/sets the definition of the limits for all retry attempts of a given policy
duration: Option<OneOfDurationOrIso8601Expression>Gets/sets the maximum duration, if any, during which to retry a given task