pub struct SchemaDefinition {
pub format: String,
pub resource: Option<ExternalResourceDefinition>,
pub document: Option<Value>,
}Expand description
Represents the definition of a schema
Fields
format: StringGets/sets the schema’s format. Defaults to ‘json’. The (optional) version of the format can be set using {format}:{version}.
resource: Option<ExternalResourceDefinition>Gets/sets the schema’s external resource, if any. Required if document has not been set.
document: Option<Value>Gets/sets the inline definition of the schema to use. Required if resource has not been set.
Implementations
Sourceimpl SchemaDefinition
impl SchemaDefinition
Sourcepub fn with_document(format: &str, document: Value) -> Self
pub fn with_document(format: &str, document: Value) -> Self
Creates a new schema definition with an inline document
Sourcepub fn with_resource(format: &str, resource: ExternalResourceDefinition) -> Self
pub fn with_resource(format: &str, resource: ExternalResourceDefinition) -> Self
Creates a new schema definition with an external resource
Sourcepub fn validate(&self) -> Result<(), SchemaValidationError>
pub fn validate(&self) -> Result<(), SchemaValidationError>
Validates that the schema definition is valid (document XOR resource)
Sourcepub fn is_document(&self) -> bool
pub fn is_document(&self) -> bool
Gets whether this schema uses an inline document
Sourcepub fn is_resource(&self) -> bool
pub fn is_resource(&self) -> bool
Gets whether this schema uses an external resource