pub enum FlowDirectiveValue {
Enumerated(FlowDirectiveType),
Custom(String),
}Expand description
Represents a typed flow directive that can be an enumerated value or a custom string
Variants
Enumerated(FlowDirectiveType)
One of the standard enumerated flow directives
Custom(String)
A custom/free-form flow directive string
Implementations
Sourceimpl FlowDirectiveValue
impl FlowDirectiveValue
Sourcepub fn is_enumerated(&self) -> bool
pub fn is_enumerated(&self) -> bool
Checks if this is one of the standard enumerated values
Sourcepub fn is_termination(&self) -> bool
pub fn is_termination(&self) -> bool
Checks if this flow directive represents a termination (exit or end)