Module for_task

Module for_task 

Structs

ForLoopDefinition
Represents the definition of a loop that iterates over a range of values
ForTaskDefinition
Represents the definition of a task that executes a set of subtasks iteratively for each element in a collection