Module fork_task

Module fork_task 

Structs

BranchingDefinition
Represents an object used to configure branches to perform concurrently
ForkTaskDefinition
Represents the configuration of a task that is composed of multiple subtasks to run concurrently