BranchingDefinition

Struct BranchingDefinition 

pub struct BranchingDefinition {
    pub branches: Map<String, TaskDefinition>,
    pub compete: bool,
}
Represents an object used to configure branches to perform concurrently

Fields

branches: Map<String, TaskDefinition>

Gets/sets a name/definition mapping of the subtasks to perform concurrently

compete: bool

Gets/sets a boolean indicating whether or not the branches should compete each other. If true and if a branch completes, it will cancel all other branches then it will return its output as the task’s output. Defaults to false per spec 1.0.3

Implementations

Source

impl BranchingDefinition

pub fn new(branches: Map<String, TaskDefinition>, compete: bool) -> Self