Module run_task

Module run_task 

Structs

ContainerLifetimeDefinition
Represents the configuration of a container’s lifetime
ContainerProcessDefinition
Represents the configuration of a container process
ProcessTypeDefinition
Represents the configuration of a process execution
RunTaskDefinition
Represents the configuration of a task used to run a given process
ScriptProcessDefinition
Represents the definition of a script evaluation process
ShellProcessDefinition
Represents the definition of a shell process
WorkflowProcessDefinition
Represents the definition of a (sub)workflow process

Enums

OneOfRunArguments
Represents a value that can be either a list of arguments (array) or a key/value mapping (object). Matches Go SDK’s RunArguments type which supports both forms.