pub struct ContainerLifetimeDefinition {
pub cleanup: String,
pub after: Option<OneOfDurationOrIso8601Expression>,
}Expand description
Represents the configuration of a container’s lifetime
Fields
cleanup: StringGets/sets the container cleanup policy to use
after: Option<OneOfDurationOrIso8601Expression>Gets/sets the duration after which to cleanup the container, in case the cleanup policy has been set to ‘eventually’