pub struct ContainerProcessDefinition {
pub image: String,
pub name: Option<String>,
pub command: Option<String>,
pub ports: Option<HashMap<String, Value>>,
pub volumes: Option<HashMap<String, Value>>,
pub environment: Option<HashMap<String, String>>,
pub stdin: Option<String>,
pub arguments: Option<Vec<String>>,
pub pull_policy: Option<String>,
pub lifetime: Option<ContainerLifetimeDefinition>,
}Expand description
Represents the configuration of a container process
Fields
image: StringGets/sets the name of the container image to run
name: Option<String>Gets/sets the name of the container to run
command: Option<String>Gets/sets the command, if any, to execute on the container
ports: Option<HashMap<String, Value>>Gets/sets a list containing the container’s port mappings, if any
Keys and values can be strings or numbers (matches Go SDK’s map[string]interface{})
volumes: Option<HashMap<String, Value>>Gets/sets the volume mapping for the container, if any
Matches Go SDK’s map[string]interface{} which allows both string and object values
environment: Option<HashMap<String, String>>Gets/sets a key/value mapping of the environment variables, if any, to use when running the configured process
stdin: Option<String>Gets/sets the data to pass to the process via stdin, if any
arguments: Option<Vec<String>>Gets/sets a list of arguments, if any, to pass to the container (argv)
pull_policy: Option<String>Gets/sets the policy that controls how the container’s image should be pulled from the registry
lifetime: Option<ContainerLifetimeDefinition>Gets/sets the configuration of the container’s lifetime