pub struct ShellProcessDefinition {
pub command: String,
pub arguments: Option<OneOfRunArguments>,
pub environment: Option<HashMap<String, String>>,
}Expand description
Represents the definition of a shell process
Fields
command: StringGets/sets the shell command to run
arguments: Option<OneOfRunArguments>Gets/sets the arguments of the shell command to run (supports both array and map forms, matches Go SDK’s RunArguments)
environment: Option<HashMap<String, String>>Gets/sets a key/value mapping of the environment variables, if any, to use when running the configured process
Implementations