pub struct WorkflowProcessDefinition {
pub namespace: String,
pub name: String,
pub version: String,
pub input: Option<Value>,
}Expand description
Represents the definition of a (sub)workflow process
Fields
namespace: StringGets/sets the namespace the workflow to run belongs to
name: StringGets/sets the name of the workflow to run
version: StringGets/sets the version of the workflow to run
input: Option<Value>Gets/sets the data, if any, to pass as input to the workflow to execute. The value should be validated against the target workflow’s input schema, if specified
Implementations