Module set_task

Module set_task 

Structs

SetTaskDefinition
Represents the definition of a task used to set data

Enums

SetValue
Represents the value that can be set in a Set task - either a map or a runtime expression string