Structs
- Error
Catcher Definition - Represents the configuration of a concept used to catch errors
- Error
Filter Definition - Represents the definition of an error filter
- Error
Filter Properties - Represents the specific properties used to filter errors
- TryTask
Definition - Represents the definition of a task used to try one or more subtasks, and to catch/handle the errors that can potentially be raised during execution