pub struct ErrorCatcherDefinition {
pub errors: Option<ErrorFilterDefinition>,
pub as_: Option<String>,
pub when: Option<String>,
pub except_when: Option<String>,
pub retry: Option<OneOfRetryPolicyDefinitionOrReference>,
pub do_: Option<Map<String, TaskDefinition>>,
}Expand description
Represents the configuration of a concept used to catch errors
Fields
errors: Option<ErrorFilterDefinition>Gets/sets the definition of the errors to catch
as_: Option<String>Gets/sets the name of the runtime expression variable to save the error as. Defaults to ‘error’.
when: Option<String>Gets/sets a runtime expression used to determine whether or not to catch the filtered error
except_when: Option<String>Gets/sets a runtime expression used to determine when NOT to catch the filtered error
retry: Option<OneOfRetryPolicyDefinitionOrReference>Gets/sets the retry policy to use, if any
do_: Option<Map<String, TaskDefinition>>Gets/sets a name/definition map of the tasks, if any, to run when catching an error