pub struct TryTaskDefinition {
pub try_: Map<String, TaskDefinition>,
pub catch: ErrorCatcherDefinition,
pub common: TaskDefinitionFields,
}Expand description
Represents the definition of a task used to try one or more subtasks, and to catch/handle the errors that can potentially be raised during execution
Fields
try_: Map<String, TaskDefinition>Gets/sets a name/definition map of the tasks to try running
catch: ErrorCatcherDefinitionGets/sets the object used to define the errors to catch
common: TaskDefinitionFieldsGets/sets the task’s common fields
Implementations
Sourceimpl TryTaskDefinition
impl TryTaskDefinition
Sourcepub fn new(
try_: Map<String, TaskDefinition>,
catch: ErrorCatcherDefinition,
) -> Self
pub fn new( try_: Map<String, TaskDefinition>, catch: ErrorCatcherDefinition, ) -> Self
Initializes a new TryTaskDefintion