pub struct WaitTaskDefinition {
pub wait: OneOfDurationOrIso8601Expression,
pub common: TaskDefinitionFields,
}Expand description
Represents the definition of a task used to wait a certain amount of time
Fields
wait: OneOfDurationOrIso8601ExpressionGets/sets the amount of time to wait before resuming workflow
common: TaskDefinitionFieldsGets/sets the task’s common fields
Implementations
Sourceimpl WaitTaskDefinition
impl WaitTaskDefinition
Sourcepub fn new(wait: OneOfDurationOrIso8601Expression) -> Self
pub fn new(wait: OneOfDurationOrIso8601Expression) -> Self
Initializes a new WaitTaskDefinition