Module workflow

Module workflow 

Structs

ComponentDefinitionCollection
Represents a collection of workflow components
ContextDataModelDefinition
Represents the definition of a workflow’s context data
RuntimeExpressionEvaluationConfiguration
Represents an object used to configure the workflow’s runtime expression evaluation
RuntimeExpressionEvaluationMode
Enumerates all supported runtime expression evaluation modes
RuntimeExpressionLanguage
Enumerates all supported runtime expression languages
RuntimeExpressions
Enumerates all supported runtime expression argument names
WorkflowDefinition
Represents the definition of a workflow
WorkflowDefinitionMetadata
Represents the metadata of a workflow, including its name, version, and description.
WorkflowScheduleDefinition
Represents the definition of a workflow’s schedule

Constants

DEFAULT_NAMESPACE
Gets the namespace to use by default for workflow definitions
LATEST_DSL_VERSION
Gets the latest ServerlessWorkflow DSL version to use by default for workflow definitions