pub struct ComponentDefinitionCollection {
pub authentications: Option<HashMap<String, ReferenceableAuthenticationPolicy>>,
pub catalogs: Option<HashMap<String, CatalogDefinition>>,
pub errors: Option<HashMap<String, ErrorDefinition>>,
pub extensions: Option<Vec<HashMap<String, ExtensionDefinition>>>,
pub functions: Option<HashMap<String, TaskDefinition>>,
pub retries: Option<HashMap<String, RetryPolicyDefinition>>,
pub secrets: Option<Vec<String>>,
pub timeouts: Option<HashMap<String, TimeoutDefinition>>,
}Expand description
Represents a collection of workflow components
Fields
authentications: Option<HashMap<String, ReferenceableAuthenticationPolicy>>Gets/sets a name/value mapping of the workflow’s reusable authentication policies
catalogs: Option<HashMap<String, CatalogDefinition>>Gets/sets a name/value mapping of the catalogs, if any, from which to import reusable components used within the workflow
errors: Option<HashMap<String, ErrorDefinition>>Gets/sets a name/value mapping of the workflow’s errors, if any
extensions: Option<Vec<HashMap<String, ExtensionDefinition>>>Gets/sets a list containing the workflow’s extensions, if any
functions: Option<HashMap<String, TaskDefinition>>Gets/sets a name/value mapping of the workflow’s reusable functions
retries: Option<HashMap<String, RetryPolicyDefinition>>Gets/sets a name/value mapping of the workflow’s reusable retry policies
secrets: Option<Vec<String>>Gets/sets a list containing the workflow’s secrets
timeouts: Option<HashMap<String, TimeoutDefinition>>Gets/sets a name/value mapping of the workflow’s reusable timeouts