pub struct ContextDataModelDefinition {
pub schema: Option<SchemaDefinition>,
pub as_: Option<Value>,
}Expand description
Represents the definition of a workflow’s context data
Fields
schema: Option<SchemaDefinition>Gets/sets the schema, if any, that defines and describes the context data
as_: Option<Value>Gets/sets a runtime expression, if any, used to set the content of the workflow context