pub struct WorkflowDefinitionMetadata {
pub dsl: String,
pub namespace: String,
pub name: String,
pub version: String,
pub title: Option<String>,
pub summary: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub metadata: Option<HashMap<String, Value>>,
}Expand description
Represents the metadata of a workflow, including its name, version, and description.
Fields
dsl: StringGets/sets the version of the DSL used to define the workflow
namespace: StringGets/sets the workflow’s namespace
Defaults to DEFAULT_NAMESPACE if not specified.
name: StringGets/sets the workflow’s name
version: StringGets/sets the workflow’s semantic version
title: Option<String>Gets/sets the workflow’s title, if any
summary: Option<String>Gets/sets the workflow’s Markdown summary, if any
Gets/sets a key/value mapping of the workflow’s tags, if any
metadata: Option<HashMap<String, Value>>Gets/sets a key/value mapping, if any, of additional information associated with the workflow document
Implementations