pub struct AsyncApiArguments {
pub document: ExternalResourceDefinition,
pub channel: Option<String>,
pub operation: Option<String>,
pub server: Option<AsyncApiServerDefinition>,
pub protocol: Option<String>,
pub message: Option<AsyncApiOutboundMessageDefinition>,
pub subscription: Option<AsyncApiSubscriptionDefinition>,
pub authentication: Option<ReferenceableAuthenticationPolicy>,
}Expand description
Represents the AsyncAPI call arguments
Fields
document: ExternalResourceDefinitionGets/sets the document that defines the AsyncAPI operation to call
channel: Option<String>Gets/sets the name of the channel (AsyncAPI v2.6.0)
operation: Option<String>Gets/sets a reference to the AsyncAPI operation to call
server: Option<AsyncApiServerDefinition>Gets/sets the server to call the specified AsyncAPI operation on
protocol: Option<String>Gets/sets the protocol to use to select the target server
message: Option<AsyncApiOutboundMessageDefinition>Gets/sets the message to publish using the target operation
subscription: Option<AsyncApiSubscriptionDefinition>Gets/sets the subscription to messages consumed using the target operation
authentication: Option<ReferenceableAuthenticationPolicy>Gets/sets the authentication policy, if any, to use when calling the AsyncAPI operation