pub struct HTTPArguments {
pub method: String,
pub endpoint: OneOfEndpointDefinitionOrUri,
pub headers: Option<OneOfHeadersOrExpression>,
pub body: Option<Value>,
pub query: Option<OneOfQueryOrExpression>,
pub output: Option<String>,
pub redirect: Option<bool>,
}Expand description
Represents the HTTP call arguments
Fields
method: StringGets/sets the HTTP method of the HTTP request to perform
endpoint: OneOfEndpointDefinitionOrUriGets/sets the HTTP endpoint to send the request to
headers: Option<OneOfHeadersOrExpression>Gets/sets a name/value mapping of the headers, if any, of the HTTP request to perform
body: Option<Value>Gets/sets the body, if any, of the HTTP request to perform
query: Option<OneOfQueryOrExpression>Gets/sets a name/value mapping of the query parameters, if any, of the HTTP request to perform
output: Option<String>Gets/sets the http call output format. Defaults to ‘content’
redirect: Option<bool>Gets/sets whether redirection status codes (300-399) should be treated as errors