Skip to main contentModule expression
Source - RuntimeExpression
- Represents a runtime expression following the Serverless Workflow DSL
${...} syntax.
- is_strict_expr
- Checks if the string is a strict runtime expression (enclosed in
${ }) - is_valid_expr
- Performs basic structural validation of a runtime expression.
- normalize_expr
- Normalizes the expression by adding
${} enclosure if not already present. - sanitize_expr
- Sanitizes the expression by removing
${} enclosure if present
and replacing single quotes with double quotes.