Module fork_task
swf_
core
1.0.0-alpha9
Module fork_
task
Module Items
Structs
In swf_
core::
models::
task
swf_core
::
models
::
task
Module
fork_
task
Structs

Branching
Definition
Represents an object used to configure branches to perform concurrently
Fork
Task
Definition
Represents the configuration of a task that is composed of multiple subtasks to run concurrently