Structs
- Container
Lifetime Definition - Represents the configuration of a container’s lifetime
- Container
Process Definition - Represents the configuration of a container process
- Process
Type Definition - Represents the configuration of a process execution
- RunTask
Definition - Represents the configuration of a task used to run a given process
- Script
Process Definition - Represents the definition of a script evaluation process
- Shell
Process Definition - Represents the definition of a shell process
- Workflow
Process Definition - Represents the definition of a (sub)workflow process
Enums
- OneOf
RunArguments - Represents a value that can be either a list of arguments (array) or a key/value mapping (object). Matches Go SDK’s RunArguments type which supports both forms.