pub struct ScriptProcessDefinition {
pub language: String,
pub code: Option<String>,
pub source: Option<ExternalResourceDefinition>,
pub stdin: Option<String>,
pub arguments: Option<OneOfRunArguments>,
pub environment: Option<HashMap<String, String>>,
}Expand description
Represents the definition of a script evaluation process
Fields
language: StringGets/sets the language of the script to run
code: Option<String>Gets/sets the script’s code. Required if ‘source’ has not been set
source: Option<ExternalResourceDefinition>Gets the the script’s source. Required if ‘code’ has not been set
stdin: Option<String>Gets/sets the data to pass to the process via stdin
arguments: Option<OneOfRunArguments>Gets/sets the arguments to pass to the script. Can be either a list of strings (argv) or a key/value mapping.
environment: Option<HashMap<String, String>>Gets/sets a key/value mapping of the environment variables, if any, to use when running the configured process
Implementations
Sourceimpl ScriptProcessDefinition
impl ScriptProcessDefinition
Sourcepub fn from_code(
language: &str,
code: String,
stdin: Option<String>,
arguments: Option<OneOfRunArguments>,
environment: Option<HashMap<String, String>>,
) -> Self
pub fn from_code( language: &str, code: String, stdin: Option<String>, arguments: Option<OneOfRunArguments>, environment: Option<HashMap<String, String>>, ) -> Self
Initializes a new script from code
Sourcepub fn from_source(
language: &str,
source: ExternalResourceDefinition,
stdin: Option<String>,
arguments: Option<OneOfRunArguments>,
environment: Option<HashMap<String, String>>,
) -> Self
pub fn from_source( language: &str, source: ExternalResourceDefinition, stdin: Option<String>, arguments: Option<OneOfRunArguments>, environment: Option<HashMap<String, String>>, ) -> Self
Initializes a new script from an external resource