pub struct TaskDefinitionFields {
pub if_: Option<String>,
pub input: Option<InputDataModelDefinition>,
pub output: Option<OutputDataModelDefinition>,
pub export: Option<OutputDataModelDefinition>,
pub timeout: Option<OneOfTimeoutDefinitionOrReference>,
pub then: Option<String>,
pub metadata: Option<HashMap<String, Value>>,
}Expand description
Holds the fields common to all tasks
Fields
if_: Option<String>Gets/sets a runtime expression, if any, used to determine whether or not the execute the task in the current context
input: Option<InputDataModelDefinition>Gets/sets the definition, if any, of the task’s input data
output: Option<OutputDataModelDefinition>Gets/sets the definition, if any, of the task’s output data
export: Option<OutputDataModelDefinition>Gets/sets the optional configuration for exporting data within the task’s context
timeout: Option<OneOfTimeoutDefinitionOrReference>Gets/sets the task’s timeout, if any
then: Option<String>Gets/sets the flow directive to be performed upon completion of the task
metadata: Option<HashMap<String, Value>>Gets/sets a key/value mapping of additional information associated with the task
Implementations