Structs
- Switch
Case Definition - Represents the definition of a case within a switch task, defining a condition and corresponding tasks to execute if the condition is met
- Switch
Task Definition - Represents the definition of a task that evaluates conditions and executes specific branches based on the result