Module try_task

Module try_task 

Structs

ErrorCatcherDefinition
Represents the configuration of a concept used to catch errors
ErrorFilterDefinition
Represents the definition of an error filter
ErrorFilterProperties
Represents the specific properties used to filter errors
TryTaskDefinition
Represents the definition of a task used to try one or more subtasks, and to catch/handle the errors that can potentially be raised during execution