Structs
- Component
Definition Collection - Represents a collection of workflow components
- Context
Data Model Definition - Represents the definition of a workflow’s context data
- Runtime
Expression Evaluation Configuration - Represents an object used to configure the workflow’s runtime expression evaluation
- Runtime
Expression Evaluation Mode - Enumerates all supported runtime expression evaluation modes
- Runtime
Expression Language - Enumerates all supported runtime expression languages
- Runtime
Expressions - Enumerates all supported runtime expression argument names
- Workflow
Definition - Represents the definition of a workflow
- Workflow
Definition Metadata - Represents the metadata of a workflow, including its name, version, and description.
- Workflow
Schedule Definition - Represents the definition of a workflow’s schedule
Constants
- DEFAULT_
NAMESPACE - Gets the namespace to use by default for workflow definitions
- LATEST_
DSL_ VERSION - Gets the latest ServerlessWorkflow DSL version to use by default for workflow definitions