pub struct WorkflowDefinition {
pub document: WorkflowDefinitionMetadata,
pub input: Option<InputDataModelDefinition>,
pub use_: Option<ComponentDefinitionCollection>,
pub timeout: Option<OneOfTimeoutDefinitionOrReference>,
pub output: Option<OutputDataModelDefinition>,
pub context: Option<ContextDataModelDefinition>,
pub schedule: Option<WorkflowScheduleDefinition>,
pub evaluate: Option<RuntimeExpressionEvaluationConfiguration>,
pub do_: Map<String, TaskDefinition>,
pub metadata: Option<HashMap<String, Value>>,
}Expand description
Represents the definition of a workflow
Fields
document: WorkflowDefinitionMetadataGets/sets an object used to document the defined workflow
input: Option<InputDataModelDefinition>Gets/sets the workflow’s input definition, if any
use_: Option<ComponentDefinitionCollection>Gets/sets a collection that contains reusable components for the workflow definition
timeout: Option<OneOfTimeoutDefinitionOrReference>Gets/sets the workflow’s timeout, if any
output: Option<OutputDataModelDefinition>Gets/sets the workflow’s output definition, if any
context: Option<ContextDataModelDefinition>Gets/sets the workflow’s context data definition, if any
schedule: Option<WorkflowScheduleDefinition>Gets/sets the definition of the workflow’s schedule, if any
evaluate: Option<RuntimeExpressionEvaluationConfiguration>Gets/sets the configuration of how the runtime expressions
do_: Map<String, TaskDefinition>Gets/sets a name/value mapping of the tasks to perform
metadata: Option<HashMap<String, Value>>Gets/sets a key/value mapping, if any, of additional information associated with the workflow
Implementations
Sourceimpl WorkflowDefinition
impl WorkflowDefinition
Sourcepub fn new(document: WorkflowDefinitionMetadata) -> Self
pub fn new(document: WorkflowDefinitionMetadata) -> Self
Initializes a new workflow definition with the given document metadata